import React, { useState, useEffect } from "react";
import Body from "./Body";
import SearchBar from "./SearchBar";
import "../styleing/layout.css";
import { api_url } from "../env";

const Layout = () => {
  const [data, setData] = useState([]);
  const [filteredData, setFilteredData] = useState([]);
  const [currentPage, setCurrentPage] = useState(1);

  const fetchData = async () => {
    try {
      const res = await fetch(api_url);
      const fetchedData = await res.json();
      setData(fetchedData);
      setFilteredData(fetchedData); 
    } catch (error) {
      console.error("Error fetching data:", error);
    }
  };


  const handleSearch = (searchTerm) => {
    if (!searchTerm) {
      setFilteredData(data); 
    } else {
      const filtered = data.filter(
        (post) =>
          post?.title.toLowerCase().includes(searchTerm.toLowerCase()) ||
          post?.body.toLowerCase().includes(searchTerm.toLowerCase())
      );
      if(filtered.length>0){
      setFilteredData([filtered[0]]); 
      }else{
        setFilteredData([]);
      }
      setCurrentPage(1); 
    }
  };

  useEffect(() => {
    fetchData(); 
  }, []);

  return (
    <div className="contentPage">
      <div className="header">
        <h2 className="heading">Latest Blogs</h2>
        <SearchBar onSearch={handleSearch} />
      </div>
      <div className="body">
        <Body
          filteredData={filteredData}
          setFilteredData={setFilteredData} 
          currentPage={currentPage}
          setCurrentPage={setCurrentPage}
        />
      </div>
    </div>
  );
};

export default Layout;
